--[[
	JabberJab :LevelJukebox
	Version: 1.0
	
	This addon plays a random tune (4 available) whenever you level up.
	The addon also plays a tune (1 available) when you die. Both of these
	tune triggers are able to be toggled off. You can also play a specific
	tune by specifying the id (1-5 is default).
	
	Tuxeh\Vandelay
	http://tuxeh.wowinterface.com
	http://www.jabberjab.com
	
	July 14th, 2010
--]]

local function print(msg, r, g, b)
	ChatFrame1:AddMessage(msg, 0.7, 0.7, 0);
end

local function LevelJukebox_Initialize(arg)
	if(jjab_LevelJukebox_Tunes == nil) then
		-- Insert default values in to the table
		jjab_LevelJukebox_Tunes = { "Interface\\AddOns\\jjab_LevelJukebox\\Tunes\\oneandonly.wav", "Interface\\AddOns\\jjab_LevelJukebox\\Tunes\\blur.wav",
						"Interface\\AddOns\\jjab_LevelJukebox\\Tunes\\boom.wav", "Interface\\AddOns\\jjab_LevelJukebox\\Tunes\\muppets.wav",
						"Interface\\AddOns\\jjab_LevelJukebox\\Tunes\\triller.wav"};
	end
	-- Play level up tunes by default
	if(jjab_LevelJukebox_Tunes_Flag == nil) then
		jjab_LevelJukebox_Tunes_Flag = true;
	end
	-- Play death tune by default
	if(jjab_LevelJukebox_DeathTunes_Flag == nil) then
		jjab_LevelJukebox_DeathTunes_Flag = true;
	end
end

local function LevelJukebox_PlayTune(arg)
	-- Randomize which tune to play
	if(arg==nil) then
		local roof = #jjab_LevelJukebox_Tunes - 1;	-- Roof is 5 by default, decrease to 4 (5 is reserved as the death tune)
	
		local nPlay = math.random(1, roof);
	
		PlaySoundFile(jjab_LevelJukebox_Tunes[nPlay]);
	else
		PlaySoundFile(jjab_LevelJukebox_Tunes[arg]);
	end
end

local function LevelJukebox_CmdHandler(arg, arg1)
	local OnOrOff;

	if(arg == "play 1") then
		LevelJukebox_PlayTune(1);
		print("LevelJukebox: Playing Tune <1>");
	elseif(arg == "play 2") then
		LevelJukebox_PlayTune(2);
		print("LevelJukebox: Playing Tune <2>");
	elseif(arg == "play 3") then
		LevelJukebox_PlayTune(3);
		print("LevelJukebox: Playing Tune <3>");
	elseif(arg == "play 4") then
		LevelJukebox_PlayTune(4);
		print("LevelJukebox: Playing Tune <4>");
	elseif(arg == "play 5") then
		LevelJukebox_PlayTune(5);
		print("LevelJukebox: Playing Tune <5>");
	elseif(arg == "toggletune") then
		jjab_LevelJukebox_Tunes_Flag = not jjab_LevelJukebox_Tunes_Flag;
		if(jjab_LevelJukebox_Tunes_Flag) then
			print("Level up tunes have been enabled.");
		else
			print("Level up tunes have been disabled.");
		end
	elseif(arg == "toggledeathtune") then
		jjab_LevelJukebox_DeathTunes_Flag = not jjab_LevelJukebox_DeathTunes_Flag;
			if(jjab_LevelJukebox_DeathTunes_Flag) then
			print("Death tunes have been enabled.");
		else
			print("Death tunes have been disabled.");
		end
	else
		print("JabberJab:LevelJukebox -- Usage: /jukebox <command>");
		print("Play <id> - Plays the tune you've specified. Tune IDs range from 1 to 5.");
		
		if(jjab_LevelJukebox_Tunes_Flag) then
			print("ToggleTune (|cff00ff00On|r) - Toggles whether or not to play a tune when you level up.");
		else
			print("ToggleTune (|cffff0000Off|r) - Toggles whether or not to play a tune when you level up.");
		end
		
		if(jjab_LevelJukebox_DeathTunes_Flag) then
			print("ToggleDeathTune (|cff00ff00On|r) - Toggles whether or not to play a tune when you die.");
		else
			print("ToggleDeathTune (|cffff0000Off|r) - Toggles whether or not to play a tune when you die.");
		end
	end
end

local function LevelJukebox_EventHandler(this, event, arg, ...)
	if(event == "ADDON_LOADED") then
		if(arg == "jjab_LevelJukebox") then
			LevelJukebox_Initialize();
		end
	end

	if(event == "PLAYER_LEVEL_UP" and jjab_LevelJukebox_Tunes_Flag == true) then
		LevelJukebox_PlayTune();
	elseif(event == "PLAYER_DEAD" and jjab_LevelJukebox_DeathTunes_Flag == true) then
		LevelJukebox_PlayTune(5);
	end

	-- Register the slashcommand
	SLASH_JUKEBOX1 = "/leveljukebox";
	SLASH_JUKEBOX2 = "/ljukebox";
	SLASH_JUKEBOX3 = "/jukebox";
	SlashCmdList["JUKEBOX"] = LevelJukebox_CmdHandler;
end

local mainFrame = CreateFrame("Frame", "MainFrame");
mainFrame:SetScript("OnEvent", LevelJukebox_EventHandler);
mainFrame:RegisterEvent("ADDON_LOADED");
mainFrame:RegisterEvent("PLAYER_LEVEL_UP");
mainFrame:RegisterEvent("PLAYER_DEAD");